@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::pm_groups;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.000';
+our $VERSION = '1.001';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -72,6 +72,9 @@ Updated with changes since November 2006, and
 received its own version number for Acme-MetaSyntactic-Themes version 1.000,
 published on May 7, 2012.
 
+Updated from the source web site for v1.001,
+published in Acme-MetaSyntactic-Themes v1.003, May 28, 2012.
+
 =head1 SEE ALSO
 
 L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
@@ -96,11 +99,13 @@ Columbus_pm
 DFW_pm
 DC_pm
 Denver_pm
+DesMoines_pm
 Gainesville_pm
 GrandRapids_pm
 HudsonValley_pm
 Houston_pm
 KansasCity_pm
+LasVegas_pm
 Madison_pm
 Minneapolis_pm
 Montreal_pm
@@ -122,7 +127,6 @@ TampaBay_pm
 Tallahassee_pm
 Toronto_pm
 Vancouver_pm
-Winnipeg_pm
 MexicoCity_pm
 Curitiba_pm
 Amsterdam_pm
@@ -207,7 +211,6 @@ WhiteMountain_pm
 NH_pm
 Kaohsiung_pm
 Kw_pm
-Canberra_pm
 PortlandMaine_pm
 Cologne_pm
 Hamburg_pm
@@ -294,3 +297,4 @@ Kerman_pm
 Mumbai_pm
 Weston_pm
 Cluj_pm
+Niigata_pm
